==> neptune_widget_toolkit-5.2.0.91.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/basic/AutosizeFrame.java <==
package com.tandbergtv.neptune.widgettoolkit.client.widget.basic;

import com.google.gwt.event.logical.shared.ResizeEvent;
import com.google.gwt.event.logical.shared.ResizeHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.google.gwt.user.client.Event;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Frame;
import com.google.gwt.user.client.ui.Widget;
import com.tandbergtv.neptune.widgettoolkit.client.application.NeptuneApplication;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.FrameWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.container.LazyContainer;

/**
 * A Frame widget that is a lazy view
 * 
 * @author mpetrusis
 */
public class AutosizeFrame extends LazyContainer {

	private Frame widget = null;
	
	private HandlerRegistration resizeHandlerRegistration;
	

	public AutosizeFrame() {
	}

	public void setUrl(String url) {
		
		this.ensureWidget();
		this.widget.setUrl (url);
	}

	@Override
	protected Widget createWidget() {
		this.widget = new FrameWidget(){
			public void onBrowserEvent(Event event) {
			    super.onBrowserEvent(event);
			    NeptuneApplication.getApplication().hideMenu();
			  }
			};
		widget.sinkEvents(Event.ONMOUSEOVER);
		widget.getElement().setAttribute("frameBorder", "0");
		widget.setStyleName("autosizeframe");
		updateIframeHeight();
		return this.widget;
	}
	
	
	private void updateIframeHeight() {
		int height = Window.getClientHeight() - NeptuneApplication.CMS_HEADER_HEIGHT_PX;
		widget.setHeight(height + "px");
	}
	
	@Override
	protected void onLoad() {
		
		super.onLoad();
		resizeHandlerRegistration = Window.addResizeHandler(new ResizeHandler() {
			public void onResize(ResizeEvent event) {
				updateIframeHeight();
			}
		});
	};

	@Override
	protected void onUnload() {
		resizeHandlerRegistration.removeHandler();
		resizeHandlerRegistration = null;
		super.onUnload();
	}
}

==> neptune_widget_toolkit-5.2.0.1015.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/basic/AutosizeFrame.java <==
package com.tandbergtv.neptune.widgettoolkit.client.widget.basic;

import com.google.gwt.dom.client.IFrameElement;
import com.google.gwt.event.dom.client.LoadHandler;
import com.google.gwt.event.logical.shared.ResizeEvent;
import com.google.gwt.event.logical.shared.ResizeHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.google.gwt.user.client.Element;
import com.google.gwt.user.client.Event;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Frame;
import com.google.gwt.user.client.ui.Widget;
import com.tandbergtv.neptune.widgettoolkit.client.application.NeptuneApplication;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.FrameWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.container.LazyContainer;

/**
 * A Frame widget that is a lazy view
 * 
 * @author mpetrusis
 */
public class AutosizeFrame extends LazyContainer {

	private Frame widget = null;
	
	private HandlerRegistration resizeHandlerRegistration;

	private LoadHandler loadHandler;
	

	public AutosizeFrame() {
	}
	
	/**
	 * add handle for onload event.
	 * @param loadHandler
	 */
	public void addOnloadHandler(LoadHandler loadHandler) {
		this.loadHandler = loadHandler;
	}

	public void setUrl(String url) {
		
		this.ensureWidget();
		this.widget.setUrl (url);
	}

	@Override
	protected Widget createWidget() {
		this.widget = new FrameWidget() {
			public void onBrowserEvent(Event event) {
				super.onBrowserEvent(event);
				NeptuneApplication.getApplication().hideMenu();
			}
			
		};
		
		if (loadHandler != null)  {
			widget.addLoadHandler(loadHandler);
		}
		
		widget.sinkEvents(Event.ONMOUSEOVER);
		widget.getElement().setAttribute("frameBorder", "0");
		widget.setStyleName("autosizeframe");

		updateIframeHeight();
		return this.widget;
	}
	
	
	private void updateIframeHeight() {
		int height = Window.getClientHeight() - NeptuneApplication.CMS_HEADER_HEIGHT_PX;
		widget.setHeight(height + "px");
	}
	
	@Override
	protected void onLoad() {
		
		super.onLoad();
		resizeHandlerRegistration = Window.addResizeHandler(new ResizeHandler() {
			public void onResize(ResizeEvent event) {
				updateIframeHeight();
			}
		});
	};

	@Override
	protected void onUnload() {
		resizeHandlerRegistration.removeHandler();
		resizeHandlerRegistration = null;
		super.onUnload();
	}
	
	public IFrameElement getIFrameWidget() {
		return IFrameElement.as(widget.getElement());
	}
	
	public Element getFrameWidgetElement() {
		return widget.getElement();
	}
}
